@@ -49,16 +49,16 @@ mpowrtext (primitive * np, nametype * tp, double x, double y) {
 }
 
 void
-mposetthick (double lthick) {
-  if (ismdistmax (lthick)) {
-    if (!ismdistmax (gslinethick)) { lthick = gslinethick; }
-    else { lthick = 0.8; }
+mposetthick (double lthk) {
+  if (ismdistmax (lthk)) {
+    if (!ismdistmax (gslinethick)) { lthk = gslinethick; }
+    else { lthk = 0.8; }
     }
-  if ((lthick < 0.0) || (lthick == gslinethick)) { return; }
+  if ((lthk < 0.0) || (lthk == gslinethick)) { return; }
   printf ("pickup pencircle scaled ");
-  wfloat (&output, lthick);
+  wfloat (&output, lthk);
   printf ("bp;\n");
-  gslinethick = lthick;
+  gslinethick = lthk;
 }
 
 void
@@ -124,7 +124,7 @@ mpocorner (postype ctr, double x, double y, double r, double ct, double st) {
 }
 
 void
-mpobox (Char * initial, postype ctr, double halfwid, double halfht,
+mpobox (char * initial, postype ctr, double halfwid, double halfht,
 	double rad) {
   double r, h, v;
 
@@ -151,7 +151,7 @@ mpobox (Char * initial, postype ctr, double halfwid, double halfht,
 }
 
 void
-mpoellipse (Char * initial, postype ctr, double halfwid, double halfht) {
+mpoellipse (char * initial, postype ctr, double halfwid, double halfht) {
   fputs (initial, stdout);
   wcoord (&output, ctr.xpos + halfwid, ctr.ypos);
   controls ();
